| N_Grams_plots | R Documentation |
Three and four word phrases common among seasons, main characters and supporting characters are summarised through a plot here, from the script data.
N_Grams_plots
A list with
1Three word pharases over seasons
2Four word pharases over seasons
3Three word pharases over main characters
4Four word pharases over main characters
5Three word pharases over supporting characters
6Four word pharases over supporting characters
length(N_Grams_plots)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.