Learn R Programming

SouthParkRshiny (version 1.0.0)

Sentiment_General_plots: Sentiment General plots

Description

Number of positive and negative words based on bing,nrc,loughran among the seasons are summarised through a plot here, from the script data.

Usage

Sentiment_General_plots

Arguments

Format

A list with

1

positive words from bing over seasons

2

negative words from bing over seasons

3

positive words from nrc over seasons

4

negative words from nrc over seasons

5

positive words from loughran over seasons

6

negative words from loughran over seasons

Examples

Run this code
length(Sentiment_General_plots)

Run the code above in your browser using DataLab