Learn R Programming

SouthParkRshiny (version 1.0.0)

SouthPark_IMDB_Data: SouthPark IMDB Data Data from the IMDB website are extracted for the show. The data consists of season, episode, primarytitle, originaltitle, year, runtime(in minutes), averagerating and number of votes.

Description

SouthPark IMDB Data Data from the IMDB website are extracted for the show. The data consists of season, episode, primarytitle, originaltitle, year, runtime(in minutes), averagerating and number of votes.

Usage

SouthPark_IMDB_Data

Arguments

Format

A dataframe with

Season

Season Number

Episode

Episode Number

PrimaryTitle

primary title of the episode

OriginalTitle

original title of the episode

Year

year the episode was aired

Runtime

runtime in minutes

AverageRating

average rating out of 10

NumberOfVotes

number of votes recorded

Examples

Run this code

sort(unique(SouthPark_IMDB_Data$Season)) # the seasons of the show
mean(SouthPark_IMDB_Data$AverageRating) # the average rating of the show
sum(SouthPark_IMDB_Data$NumberOfVotes) # sum of the number of votes

Run the code above in your browser using DataLab