| SouthPark_Script_Data | R Documentation |
Data for the scripts scraped from the website are stored here. The data consists of season, episode, character and line.
SouthPark_Script_Data
A dataframe with
SeasonSeason Number
EpisodeEpisode Number
CharacterCharacter Name
LineThe lines the character spoke
unique(SouthPark_Script_Data$Season) # the seasons of the show
unique(SouthPark_Script_Data$Character) |> length() # the unique characters in the show
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.