Learn R Programming

SouthParkRshiny (version 1.0.0)

Swear_Words_plots: Swear words plots

Description

Swear word plots for main and supporting characters per seasons. Total number of words and unique words are summarised through plots.

Usage

Swear_Words_plots

Arguments

Format

A list with

1

Swear words in general

2

Swear words for main characters

3

Swear words for supporting characters

Examples

Run this code
length(Swear_Words_plots)

Run the code above in your browser using DataLab