Learn R Programming

SouthParkRshiny (version 1.0.0)

N_Grams_plots: N Grams plots

Description

Three and four word phrases common among seasons, main characters and supporting characters are summarised through a plot here, from the script data.

Usage

N_Grams_plots

Arguments

Format

A list with

1

Three word pharases over seasons

2

Four word pharases over seasons

3

Three word pharases over main characters

4

Four word pharases over main characters

5

Three word pharases over supporting characters

6

Four word pharases over supporting characters

Examples

Run this code
length(N_Grams_plots)

Run the code above in your browser using DataLab