Learn R Programming

SouthParkRshiny (version 1.0.0)

SouthPark_Script_Data: SouthPark Script Data

Description

Data for the scripts scraped from the website are stored here. The data consists of season, episode, character and line.

Usage

SouthPark_Script_Data

Arguments

Format

A dataframe with

Season

Season Number

Episode

Episode Number

Character

Character Name

Line

The lines the character spoke

Examples

Run this code
unique(SouthPark_Script_Data$Season) # the seasons of the show
unique(SouthPark_Script_Data$Character) |> length() # the unique characters in the show

Run the code above in your browser using DataLab